@@ -10,7 +10,7 @@ class TestTranslatePagination:
         assert pag.page_size <= 500, "Page size should not be greater than 500"
         assert pag.max_page_size <= 800, "Max page size should not be greater than 800"
 
-    def test_paginated_response(self, make_request, import_translations_fixture):
+    def test_paginated_response(self, make_request, import_german_translations_fixture):
         from translate.service.views import TranslationsAPIView
 
         kwargs = {"language": "de"}
